@@ -8,12 +8,18 @@ from . import link_maker
 from flask_classful import FlaskView,route
 import random
 from urllib.parse import urlparse
+import user_agents
+
+
 class UserView(FlaskView):
 
     def index(self):
         
         c=get_common_data(g.user_uuid)
-        return render_template('home/index.html',**c)
+        user_agent =  user_agents.parse(request.user_agent.string)
+        
+        
+        return render_template('home/index.html',**c,ua=user_agent)
         
 
     @route('/clash/<meta_or_normal>/proxies.yml')
@@ -60,9 +66,11 @@ def do_base_64(str):
 def get_common_data(user_uuid):
     
     
-    o = urlparse(request.base_url)
-    db_domain=Domain.query.filter(Domain.domain==o.hostname).first()
-    domain=o.hostname
+    
+    domain=urlparse(request.base_url).hostname
+    
+    db_domain=Domain.query.filter(Domain.domain==domain).first()
+    
     direct_host= domain
     g.is_cdn=False
     g.cdn_forced_host=domain
